import { TerminalStage } from '../../stages';
/**
 * Return a terminal stage that performs a reduction of the received pipeline elements using the
 * provided* `reducer` function, optionally accepting an initial value as the second argument.
 *
 * The `reducer` function accepts 2 arguments, the first argument is the accumulator value that will
 * be returned when the reduction is complete, the second argument is the next pipeline element to
 * reduce into the accumulator.
 *
 * This collector's behavior is similar to that of
 * {@link https://developer.mozilla.org/en-US/docs/Web/JavaScript/Reference/Global_Objects/Array/reduce#description Array.prototype.reduce}.
 *
 * @param reducer The function used to reduce the incoming pipeline elements.
 * @param initialValue The optional initial value used for the reduction.
 *
 * @template IN The type parameter of each incoming element in the pipeline.
 *
 * @returns
 */
export declare function reduce<IN, OUT>(reducer: (accumulator: OUT, next: IN) => OUT, initialValue?: OUT): TerminalStage<IN, OUT>;
export declare function reduce<IN>(reducer: (accumulator: IN, next: IN) => IN): TerminalStage<IN, IN>;
